@@ -9,7 +9,7 @@
  * Copyright (C) 2002  Terence M. Welsh
  *
  * Euphoria is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as 
+ * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
  *
  * Euphoria is distributed in the hope that it will be useful,
@@ -409,7 +409,7 @@ void wisp::draw()
 void wisp::drawAsBackground()
 {
 	int i, j;
-	
+
 	glPushMatrix();
 	glTranslatef(c[0] * 0.2f, c[1] * 0.2f, 1.6f);
 
@@ -591,7 +591,7 @@ void EuphoriaWidget::paintGL()
 	else
 		glClear(GL_COLOR_BUFFER_BIT);
 
-	// 
+	//
 	for(i=0; i<dBackground; i++)
 		_backwisps[i].drawAsBackground();
 	for(i=0; i<dWisps; i++)
@@ -896,16 +896,16 @@ void EuphoriaWidget::setDefaults(int which)
 // libkscreensaver interface
 extern "C"
 {
-    const char* kss_applicationName = "keuphoria.kss";
-    const char* kss_description = I18N_NOOP( "Euphoria" );
-    const char* kss_version = "1.0";
+    KDE_EXPORT const char* kss_applicationName = "keuphoria.kss";
+    KDE_EXPORT const char* kss_description = I18N_NOOP( "Euphoria" );
+    KDE_EXPORT const char* kss_version = "1.0";
 
-    KScreenSaver* kss_create( WId id )
+    KDE_EXPORT KScreenSaver* kss_create( WId id )
     {
         return new KEuphoriaScreenSaver( id );
     }
 
-    QDialog* kss_setup()
+    KDE_EXPORT QDialog* kss_setup()
     {
         return new KEuphoriaSetup;
     }
@@ -1036,7 +1036,7 @@ KEuphoriaSetup::~KEuphoriaSetup()
 
 void KEuphoriaSetup::slotHelp()
 {
-    KMessageBox::about(this, 
+    KMessageBox::about(this,
         i18n("<h3>Euphoria 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
         QString::null, KMessageBox::AllowLink);
 }
