@@ -9,7 +9,7 @@
  * Copyright (C) 2002  Terence M. Welsh
  *
  * Flux is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as 
+ * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
  *
  * Flux is distributed in the hope that it will be useful,
@@ -776,16 +776,16 @@ void FluxWidget::updateParameters()
 // libkscreensaver interface
 extern "C"
 {
-    const char* kss_applicationName = "kflux.kss";
-    const char* kss_description = I18N_NOOP( "Flux" );
-    const char* kss_version = "1.0";
+    KDE_EXPORT const char* kss_applicationName = "kflux.kss";
+    KDE_EXPORT const char* kss_description = I18N_NOOP( "Flux" );
+    KDE_EXPORT const char* kss_version = "1.0";
 
-    KScreenSaver* kss_create( WId id )
+    KDE_EXPORT KScreenSaver* kss_create( WId id )
     {
         return new KFluxScreenSaver( id );
     }
 
-    QDialog* kss_setup()
+    KDE_EXPORT QDialog* kss_setup()
     {
         return new KFluxSetup;
     }
@@ -913,7 +913,7 @@ KFluxSetup::~KFluxSetup()
 
 void KFluxSetup::slotHelp()
 {
-    KMessageBox::about(this, 
+    KMessageBox::about(this,
         i18n("<h3>Flux 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
         QString::null, KMessageBox::AllowLink);
 }
