@@ -9,7 +9,7 @@
  * Copyright (C) 2002  Terence M. Welsh
  *
  * Solar Winds is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as 
+ * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
  *
  * Solar Winds is distributed in the hope that it will be useful,
@@ -176,7 +176,7 @@ void wind::update()
             ct[i] -= PIx2;
         c[i] = cos(ct[i]);
     }
-    
+
     // calculate emissions
     for(i=0; i<emitCount; i++)
     {
@@ -594,16 +594,16 @@ void SWindsWidget::setDefaults(int which)
 // libkscreensaver interface
 extern "C"
 {
-    const char* kss_applicationName = "ksolarwinds.kss";
-    const char* kss_description = I18N_NOOP( "Solar Winds" );
-    const char* kss_version = "1.0";
+    KDE_EXPORT const char* kss_applicationName = "ksolarwinds.kss";
+    KDE_EXPORT const char* kss_description = I18N_NOOP( "Solar Winds" );
+    KDE_EXPORT const char* kss_version = "1.0";
 
-    KScreenSaver* kss_create( WId id )
+    KDE_EXPORT KScreenSaver* kss_create( WId id )
     {
         return new KSWindsScreenSaver( id );
     }
 
-    QDialog* kss_setup()
+    KDE_EXPORT QDialog* kss_setup()
     {
         return new KSWindsSetup;
     }
