@@ -36,16 +36,16 @@
 // libkscreensaver interface
 extern "C"
 {
-	const char *kss_applicationName = "kgravity.kss";
-	const char *kss_description = I18N_NOOP( "Particle Gravity Screen Saver" );
-	const char *kss_version = "2.2.0";
+	KDE_EXPORT const char *kss_applicationName = "kgravity.kss";
+	KDE_EXPORT const char *kss_description = I18N_NOOP( "Particle Gravity Screen Saver" );
+	KDE_EXPORT const char *kss_version = "2.2.0";
 
-	KScreenSaver *kss_create( WId id )
+	KDE_EXPORT KScreenSaver *kss_create( WId id )
 	{
 		return new KGravitySaver( id );
 	}
 
-	QDialog *kss_setup()
+	KDE_EXPORT QDialog *kss_setup()
 	{
 		return new KGravitySetup();
 	}
