@@ -7,7 +7,7 @@
 //
 // Developed by Georg Drenkhahn, georg-d@users.sourceforge.net
 //
-// $Id: pendulum.cpp,v 1.3 2004/05/16 14:39:39 mhunter Exp $
+// $Id: pendulum.cpp 376058 2005-01-07 11:14:10Z mlaurent $
 //
 /*
  * Copyright (C) 2004 Georg Drenkhahn
@@ -55,21 +55,21 @@
 extern "C"
 {
    /// application name for libkscreensaver interface
-   const char *kss_applicationName = "kpendulum.kss";
+   KDE_EXPORT const char *kss_applicationName = "kpendulum.kss";
    /// application description for libkscreensaver interface
-   const char *kss_description = I18N_NOOP("Simulation of\
+   KDE_EXPORT const char *kss_description = I18N_NOOP("Simulation of\
  a two-part pendulum");
    /// application version for libkscreensaver interface
-   const char *kss_version = KPENDULUM_VERSION;
+   KDE_EXPORT const char *kss_version = KPENDULUM_VERSION;
 
    /// function to create screen saver object
-   KScreenSaver* kss_create(WId id)
+   KDE_EXPORT KScreenSaver* kss_create(WId id)
    {
       return new KPendulumSaver(id);
    }
 
    /// function to create setup dialog for screen saver
-   QDialog* kss_setup()
+   KDE_EXPORT QDialog* kss_setup()
    {
       return new KPendulumSetup();
    }
