@@ -54,16 +54,16 @@
 // libkscreensaver interface
 extern "C"
 {
-    const char *kss_applicationName = "kscience.kss";
-    const char *kss_description = I18N_NOOP( "Science Screen Saver" );
-    const char *kss_version = "2.2.0";
+    KDE_EXPORT const char *kss_applicationName = "kscience.kss";
+    KDE_EXPORT const char *kss_description = I18N_NOOP( "Science Screen Saver" );
+    KDE_EXPORT const char *kss_version = "2.2.0";
 
-    KScreenSaver *kss_create( WId id )
+    KDE_EXPORT KScreenSaver *kss_create( WId id )
     {
         return new KScienceSaver( id );
     }
 
-    QDialog *kss_setup()
+    KDE_EXPORT QDialog *kss_setup()
     {
         return new KScienceSetup();
     }
@@ -185,7 +185,7 @@ void KScienceSaver::initialize()
 	y = (hs > 0) ? (rnd.getDouble() * hs ) : 0.0;
 
 	xcoord = (int) x;
-	ycoord = (int) y;		
+	ycoord = (int) y;
 
 	switch( bpp ) {
 		case 1 : applyLens = &KScienceSaver::applyLens8bpp;  break;
@@ -204,7 +204,7 @@ void KScienceSaver::initWhirlLens()
 	T32bit xo, yo;
 
 	intens = double( intensity[mode] + 1) / 5.0;
-	if( inverse[mode] ) 
+	if( inverse[mode] )
 		intens = -intens;
 
 	for(int y = side-1; y >= 0; y--)
@@ -226,8 +226,8 @@ void KScienceSaver::initWhirlLens()
 			    phi +=  intens * ( radius - r ) / ( r+7.0 );
 			    xo = (T32bit) ( origin + r*cos( phi ) - x );
 			    yo = (T32bit) ( origin + r*sin( phi ) - y );
-			    off[x] = xo*bpp + yo*imgnext;				
-		    } 		 			
+			    off[x] = xo*bpp + yo*imgnext;
+		    }
 		    else
 			if( hideBG[mode] )
 				off[x] = (border-y)*imgnext + (border-x)*bpp;
@@ -267,8 +267,8 @@ void KScienceSaver::initSphereLens()
 			phi = (yr != 0.0) ? asin(dy/yr) : 0.0;
 			yo = (T32bit) (origin + intens*2.0*phi*yr / M_PI - y);
 			off[x] = xo*bpp + yo*imgnext;
-		} 		 			
-		else 
+		}
+		else
 			if( hideBG[mode] )
 				off[x] = (border-y)*imgnext + (border-x)*bpp;
 			else
@@ -309,7 +309,7 @@ void KScienceSaver::initExponentialLens()
 			    }
 			    xo = (T32bit) ( origin + f*dx - x );
 			    yo = (T32bit) ( origin + f*dy - y );
-			    off[x] = xo*bpp + yo*imgnext;			
+			    off[x] = xo*bpp + yo*imgnext;
 		    }
 		    else
 			if( hideBG[mode] )
@@ -321,12 +321,12 @@ void KScienceSaver::initExponentialLens()
 }
 
 void KScienceSaver::initCurvatureLens()
-{ 
-	double dx, dy, r, f, intens; 
-	T32bit *off; 
-	T32bit xo, yo; 
- 
-	intens = (double) radius*intensity[mode] / 20.0; 
+{
+	double dx, dy, r, f, intens;
+	T32bit *off;
+	T32bit xo, yo;
+
+	intens = (double) radius*intensity[mode] / 20.0;
 	if( inverse[mode] ) intens = -intens;
 
 	for(int y = side-1; y >= 0; y--)
@@ -339,34 +339,34 @@ void KScienceSaver::initCurvatureLens()
 		    dx = x - origin;
 		    r = sqrt( dx*dx + dy*dy );
 
-		    if( r < radius ) 
-		    { 
+		    if( r < radius )
+		    {
 			    if( r == 0.0 )
 				    f = 0.0;
 			    else
 				    f = (r - intens * sin(M_PI * r/(double)radius)) / r;
 			    xo = (T32bit) ( origin + f*dx - x );
 			    yo = (T32bit) ( origin + f*dy - y );
-			    off[x] = xo*bpp + yo*imgnext;			
-		    } 
+			    off[x] = xo*bpp + yo*imgnext;
+		    }
 		    else
 			if( hideBG[mode] )
 				off[x] = (border-y)*imgnext + (border-x)*bpp;
 			else
 				off[x] = 0;
-		} 
-	} 
-} 
+		}
+	}
+}
 
 void KScienceSaver::initWaveLens()
-{ 
-	double dx, dy, r, rnew, f, intens, k; 
-	T32bit *off; 
-	T32bit xo, yo; 
- 
-	intens = (double) intensity[mode] + 1.0; 
+{
+	double dx, dy, r, rnew, f, intens, k;
+	T32bit *off;
+	T32bit xo, yo;
+
+	intens = (double) intensity[mode] + 1.0;
 	k = (intensity[mode] % 2) ? -12.0 : 12.0;
- 
+
 	for(int y = side-1; y >= 0; y--)
 	{
 		dy = y - origin;
@@ -377,8 +377,8 @@ void KScienceSaver::initWaveLens()
 		    dx = x - origin;
 		    r = sqrt( dx*dx + dy*dy );
 
-		    if( r < radius ) 
-		    { 
+		    if( r < radius )
+		    {
 			    if( r == 0.0 )
 				    f = 0.0;
 			    else
@@ -388,16 +388,16 @@ void KScienceSaver::initWaveLens()
 			    }
 			    xo = (T32bit) ( origin + f*dx - x );
 			    yo = (T32bit) ( origin + f*dy - y );
-			    off[x] = xo*bpp + yo*imgnext;			
-		    } 
+			    off[x] = xo*bpp + yo*imgnext;
+		    }
 		    else
 			if( hideBG[mode] )
 				off[x] = (border-y)*imgnext + (border-x)*bpp;
 			else
 				off[x] = 0;
-		} 
-	} 
-} 
+		}
+	}
+}
 
 void KScienceSaver::initLens()
 {
@@ -412,7 +412,7 @@ void KScienceSaver::initLens()
 	side  = origin << 1;
 
 	d->buffer = XSubImage( d->xRootWin, 0, 0, side, side );
-        myAssert( d->buffer != 0, "can't allocate pixmap" );                             
+        myAssert( d->buffer != 0, "can't allocate pixmap" );
 
 	d->offset = (T32bit **) malloc( sizeof(T32bit *) * side );
 	myAssert( d->offset != 0, "too few memory" );
@@ -431,7 +431,7 @@ void KScienceSaver::initLens()
 void KScienceSaver::releaseLens()
 {
 	if( d->offset != 0 ) {
-		for(int i=0; i<side; i++) 
+		for(int i=0; i<side; i++)
     			if( d->offset[i] != 0 ) free( d->offset[i] );
     		free( d->offset );
 		d->offset = 0;
@@ -461,27 +461,27 @@ void KScienceSaver::setMode( int m )
 			do_refresh( QRect( (int) x+diam, (int) y,      dm-diam, diam    ) );
 			do_refresh( QRect( (int) x,      (int) y+diam, dm,      dm-diam ) );
 		}
-	
+
 	timer.start( SCI_MAX_SPEED - speed[mode] );
 }
 
 void KScienceSaver::setMoveX( int s )
 {
 	timer.stop();
-	
+
 	moveX[mode] = s;
 	vx = copysign( moveX[mode], vx );
-	
+
 	timer.start( SCI_MAX_SPEED - speed[mode] );
 }
 
 void KScienceSaver::setMoveY( int s )
 {
 	timer.stop();
-	
+
 	moveY[mode] = s;
 	vy = copysign( moveY[mode], vy );
-	
+
 	timer.start( SCI_MAX_SPEED - speed[mode] );
 }
 
@@ -517,7 +517,7 @@ void KScienceSaver::setSpeed( int s )
 void KScienceSaver::setIntensity( int i )
 {
 	timer.stop();
-	
+
 	releaseLens();
 	intensity[mode] = i;
 	initLens();
@@ -551,27 +551,27 @@ void KScienceSaver::setGravity( bool b )
 void KScienceSaver::setHideBG( bool b )
 {
 	timer.stop();
-	
+
 	releaseLens();
 	hideBG[mode] = b;
-	initLens();	
+	initLens();
 	do_refresh( QRect( 0, 0, width(), height() ) );
-		
-	timer.start( SCI_MAX_SPEED - speed[mode]);	
+
+	timer.start( SCI_MAX_SPEED - speed[mode]);
 }
 
 void KScienceSaver::readSettings()
 {
     KConfig *config = KGlobal::config();
         QString sMode;
-  
+
 	config->setGroup( "Settings" );
 	mode = config->readNumEntry( "ModeNr", SCI_DEFAULT_MODE );
 
 	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		config->setGroup( "Mode" + sMode ); 
+		config->setGroup( "Mode" + sMode );
 		moveX[i]     = config->readNumEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
 		moveY[i]     = config->readNumEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
 		size[i]      = config->readNumEntry(  "Size",      SCI_DEFAULT_SIZE);
@@ -588,22 +588,22 @@ void KScienceSaver::readSettings()
 
 void KScienceSaver::do_refresh( const QRect & rect )
 {
-	if( grabPixmap ) 
+	if( grabPixmap )
 		return;
 	rect.normalize();
 
 	if( hideBG[mode] )
 	{
 		XSetWindowBackground( qt_xdisplay(), winId(), black.pixel() );
-		XClearArea( qt_xdisplay(), winId(), rect.left(), rect.top(), 
+		XClearArea( qt_xdisplay(), winId(), rect.left(), rect.top(),
                             rect.width(), rect.height(), false );
 	}
-	else 
+	else
 	{
 		myAssert( d->xRootWin != 0, "root window not grabbed" );
-		XPutImage( qt_xdisplay(), winId(), d->gc, d->xRootWin, 
+		XPutImage( qt_xdisplay(), winId(), d->gc, d->xRootWin,
 		           rect.left(), rect.top(),
-                           rect.left(), rect.top(), 
+                           rect.left(), rect.top(),
                            rect.width(), rect.height() );
 	}
 }
@@ -635,23 +635,23 @@ void KScienceSaver::slotTimeout()
 		y += vy;
 	}
 
-	if( x <= 0.0 ) { 
-		vx = -vx; 
-		x = 0.0; 
+	if( x <= 0.0 ) {
+		vx = -vx;
+		x = 0.0;
 	}
-	if( int(x) + diam >= width()) { 
-		vx = -vx; 
+	if( int(x) + diam >= width()) {
+		vx = -vx;
 		myAssert( width()-diam > 0, "assertion violated: width-diam > 0" );
-		x = (double) (width() - diam - 1); 
+		x = (double) (width() - diam - 1);
 	}
-	if( y <= 0.0 ) { 
-		vy = -vy; 
-		y = 0.0; 
+	if( y <= 0.0 ) {
+		vy = -vy;
+		y = 0.0;
 	}
-	if( int(y) + diam >= height() ) { 
-		vy = -vy; 
+	if( int(y) + diam >= height() ) {
+		vy = -vy;
 		myAssert( height() - diam > 0, "assertion violated: height-diam > 0" );
-		y = (double) (height() - diam - 1); 
+		y = (double) (height() - diam - 1);
 	}
 
 	xcoord = (int) x ;
@@ -662,7 +662,7 @@ void KScienceSaver::slotTimeout()
 
 	if( dx > 0 ) {
 		w = diam+dx;
-		xd = oldx;		
+		xd = oldx;
 		xs = border-dx;
 		if( dy > 0 ) {
 			h = diam+dy;
@@ -693,7 +693,7 @@ void KScienceSaver::slotTimeout()
 	if( (unsigned int) xd + w >= width()  ) w = width()  - xd - 1;
 	if( (unsigned int) yd + h >= height() ) h = height() - yd - 1;
 
-//printf("%d: (dx: %3d, dy: %3d), diam: %3d, (xc: %3d, yc: %3d), (xs: %3d, ys: %3d), (xd: %3d, yd: %3d), (w: %3d, h: %3d)\n", mode, dx, dy, diam, xcoord, ycoord, xs, ys, xd, yd, w, h);	
+//printf("%d: (dx: %3d, dy: %3d), diam: %3d, (xc: %3d, yc: %3d), (xs: %3d, ys: %3d), (xd: %3d, yd: %3d), (w: %3d, h: %3d)\n", mode, dx, dy, diam, xcoord, ycoord, xs, ys, xd, yd, w, h);
 	myAssert( dx <= border && dy <=border, "assertion violated: dx or dy <= border");
 	myAssert( xcoord >= 0 && ycoord >= 0, "assertion violated: xcoord, ycoord >= 0 ");
 	myAssert( (unsigned int) xd+w < width(), "assertion violated: xd+w < width" );
@@ -736,7 +736,7 @@ void KScienceSaver::grabPreviewWidget()
 	myAssert( d->xRootWin, "unable to grab preview window\n" );
 
 	imgnext = d->xRootWin->bytes_per_line;
-	bpp = ( d->xRootWin->bits_per_pixel ) >> 3;		
+	bpp = ( d->xRootWin->bits_per_pixel ) >> 3;
 }
 
 void KScienceSaver::blackPixel( int x, int y )
@@ -775,7 +775,7 @@ void KScienceSaver::applyLens8bpp(int xs, int ys, int xd, int yd, int w, int h)
 			*data++ = img2++[*off++];
 		img1 += imgnext;
 		data += datanext;
-	} 
+	}
 
 }
 
@@ -797,9 +797,9 @@ void KScienceSaver::applyLens16bpp(int xs, int ys, int xd, int yd, int w, int h)
 		}
 		img1 += imgnext;
 		data += datanext;
-	} 
+	}
 }
-	
+
 void KScienceSaver::applyLens24bpp(int xs, int ys, int xd, int yd, int w, int h)
 {
 	T32bit *off;
@@ -819,7 +819,7 @@ void KScienceSaver::applyLens24bpp(int xs, int ys, int xd, int yd, int w, int h)
 		}
 		img1 += imgnext;
 		data += datanext;
-	} 
+	}
 }
 
 void KScienceSaver::applyLens32bpp(int xs, int ys, int xd, int yd, int w, int h)
@@ -842,7 +842,7 @@ void KScienceSaver::applyLens32bpp(int xs, int ys, int xd, int yd, int w, int h)
 		}
 		img1 += imgnext;
 		data += datanext;
-	} 
+	}
 }
 
 
@@ -862,7 +862,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	lt->addLayout( ltm );
 	QVBoxLayout *ltc = new QVBoxLayout;
 	lt->addLayout( ltc );
-	
+
 	// mode
 	QLabel *label = new QLabel( i18n("Mode:"), main );
 	ltm->addWidget( label );
@@ -881,24 +881,24 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	cbox->setChecked( inverse[mode] );
 	connect( cbox, SIGNAL( clicked() ), SLOT( slotInverse() ) );
 	ltm->addWidget( cbox );
-	
-	// gravity 
+
+	// gravity
 	cbox = checkGravity = new QCheckBox( i18n("Gravity"), main );
 	cbox->setChecked( gravity[mode] );
 	connect( cbox, SIGNAL( clicked() ), SLOT( slotGravity() ) );
 	ltm->addWidget( cbox );
-		
+
 	// hide background
 	cbox = checkHideBG = new QCheckBox( i18n("Hide background"), main );
 	cbox->setChecked( hideBG[mode] );
 	connect( cbox, SIGNAL( clicked() ), SLOT( slotHideBG() ) );
-	ltm->addWidget( cbox );		
+	ltm->addWidget( cbox );
 	ltm->addStretch();
-		
-	// size 	
+
+	// size
 	label = new QLabel( i18n("Size:"), main );
 	ltc->addWidget( label );
-		
+
 	slideSize = new QSlider(9, 50, 5, size[mode], QSlider::Horizontal,
                                 main );
 	slideSize->setMinimumSize( 90, 20 );
@@ -916,7 +916,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	// intensity
 	label = new QLabel( i18n("Intensity:"), main );
 	ltc->addWidget( label );
-		
+
 	slideIntensity = new QSlider(0, 10, 1, intensity[mode],
                                      QSlider::Horizontal, main );
 	slideIntensity->setMinimumSize( 90, 20 );
@@ -933,7 +933,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	// speed
 	label = new QLabel( i18n("Speed:"), main );
 	ltc->addWidget( label );
-	
+
 	slideSpeed = new QSlider(0, SCI_MAX_SPEED, 10, speed[mode],
                              QSlider::Horizontal, main );
 	slideSpeed->setMinimumSize( 90, 20 );
@@ -949,7 +949,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 
 	QHBoxLayout *ltcm = new QHBoxLayout;
 	ltc->addLayout( ltcm );
-	
+
 	slideMoveX = new QSlider(0, SCI_MAX_MOVE, 5, moveX[mode],
                                  QSlider::Horizontal, main );
 	slideMoveX->setMinimumSize( 40, 20 );
@@ -1016,10 +1016,10 @@ void KScienceSetup::readSettings()
 	config->setGroup( "Settings" );
 	mode = config->readNumEntry( "ModeNr", SCI_DEFAULT_MODE );
 
-	for(int i=0; i < MAX_MODES; i++) 
+	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		config->setGroup( "Mode" + sMode ); 
+		config->setGroup( "Mode" + sMode );
 		moveX[i]     = config->readNumEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
 		moveY[i]     = config->readNumEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
 		size[i]      = config->readNumEntry(  "Size",      SCI_DEFAULT_SIZE);
@@ -1052,7 +1052,7 @@ void KScienceSetup::slotInverse( )
 void KScienceSetup::slotGravity( )
 {
 	gravity[mode] = checkGravity->isChecked();
-	
+
 	if( saver )
 		saver->setGravity( gravity[mode] );
 }
@@ -1060,7 +1060,7 @@ void KScienceSetup::slotGravity( )
 void KScienceSetup::slotHideBG( )
 {
 	hideBG[mode] = checkHideBG->isChecked();
-	
+
 	if( saver )
 		saver->setHideBG( hideBG[mode] );
 }
@@ -1068,7 +1068,7 @@ void KScienceSetup::slotHideBG( )
 void KScienceSetup::slotMoveX( int x )
 {
 	moveX[mode] = x;
-	
+
 	if( saver )
 		saver->setMoveX( x );
 }
@@ -1076,7 +1076,7 @@ void KScienceSetup::slotMoveX( int x )
 void KScienceSetup::slotMoveY( int y )
 {
 	moveY[mode] = y;
-	
+
 	if( saver )
 		saver->setMoveY( y );
 }
