@@ -45,23 +45,23 @@
 
 
 #define SLIDESHOW_VERSION "2.3.0"
-static const char *version = SLIDESHOW_VERSION;
-static const char *description = I18N_NOOP("KSlideshow");
+static const char version[] = SLIDESHOW_VERSION;
+static const char description[] = I18N_NOOP("KSlideshow");
 
 
 // libkscreensaver interface
 extern "C"
 {
-    const char *kss_applicationName = "kslideshow.kss";
-    const char *kss_description = I18N_NOOP( "KSlideshow" );
-    const char *kss_version = SLIDESHOW_VERSION;
+    KDE_EXPORT const char *kss_applicationName = "kslideshow.kss";
+    KDE_EXPORT const char *kss_description = I18N_NOOP( "KSlideshow" );
+    KDE_EXPORT const char *kss_version = SLIDESHOW_VERSION;
 
-    KScreenSaver *kss_create( WId id )
+    KDE_EXPORT KScreenSaver *kss_create( WId id )
     {
         return new kSlideShowSaver( id );
     }
 
-    QDialog *kss_setup()
+    KDE_EXPORT QDialog *kss_setup()
     {
         return new kSlideShowSetup();
     }
@@ -135,7 +135,7 @@ void kSlideShowSaver::readConfig()
   mShowRandom = config->readBoolEntry("ShowRandom", true);
   mZoomImages = config->readBoolEntry("ZoomImages", false);
   mPrintName = config->readBoolEntry("PrintName", true);
-  mDirectory = config->readPathEntry("Directory", QDir::homeDirPath());
+  mDirectory = config->readPathEntry("Directory", KGlobal::dirs()->findDirs("wallpaper", "").last());
   mDelay = config->readNumEntry("Delay", 10) * 1000;
   mSubdirectory = config->readBoolEntry("SubDirectory", false);
   mRandomPosition = config->readBoolEntry("RandomPosition", false);
@@ -810,13 +810,14 @@ void kSlideShowSaver::loadNextImage()
   QString fname;
   int num;
 
+  num = mFileList.count();
+  if (num <= 0) //no files in the directory
+  {
+    return;
+  }
+
   if (mShowRandom)
   {
-    num = mFileList.count();
-    if (num <= 0) //no files in the directory
-    {
-      return;
-    }
     mFileIdx = rand() % num;
     fname = mFileList[mFileIdx];
     mFileList.remove(fname);
@@ -827,7 +828,6 @@ void kSlideShowSaver::loadNextImage()
   }
   else
   {
-    num = mFileList.count();
     if (mFileIdx >= num) mFileIdx = 0;
     fname = mFileList[mFileIdx];
   }
@@ -836,6 +836,7 @@ void kSlideShowSaver::loadNextImage()
   {
     kdDebug() << "Failed to load image " << fname << endl;
     mFileList.remove(fname);
+    mRandomList.remove(fname);
     if (!mFileList.isEmpty())
         loadNextImage();
     return;
@@ -863,7 +864,11 @@ void kSlideShowSaver::loadDirectory()
 void kSlideShowSaver::traverseDirectory(const QString &dirName)
 {
   QDir dir(dirName);
-  dir.setFilter(QDir::Dirs | QDir::Files | QDir::NoSymLinks);
+  if (!dir.exists())
+  {
+     return ;
+  }
+  dir.setFilter(QDir::Dirs | QDir::Files);
 
   const QFileInfoList *fileinfolist = dir.entryInfoList();
   QFileInfoListIterator it(*fileinfolist);
