@@ -38,16 +38,16 @@
 
 extern "C"
 {
-	const char *kss_applicationName = "kwave.kss";
-	const char *kss_description = I18N_NOOP( "Bitmap Wave Screen Saver" );
-	const char *kss_version = "2.2.0";
+	KDE_EXPORT const char *kss_applicationName = "kwave.kss";
+	KDE_EXPORT const char *kss_description = I18N_NOOP( "Bitmap Wave Screen Saver" );
+	KDE_EXPORT const char *kss_version = "2.2.0";
 
-	KScreenSaver *kss_create( WId id )
+	KDE_EXPORT KScreenSaver *kss_create( WId id )
 	{
 		return new KWaveSaver( id );
 	}
 
-	QDialog *kss_setup()
+	KDE_EXPORT QDialog *kss_setup()
 	{
 		return new KWaveSetup();
 	}
