@@ -58,17 +58,17 @@ bool g_inited = false;
 
 extern "C"
 {
-    const char *kss_applicationName = "kpartsaver";
-    const char *kss_description = I18N_NOOP( "KPart Screen Saver" );
-    const char *kss_version = "1.0";
+    KDE_EXPORT const char *kss_applicationName = "kpartsaver";
+    KDE_EXPORT const char *kss_description = I18N_NOOP( "KPart Screen Saver" );
+    KDE_EXPORT const char *kss_version = "1.0";
 
-    KScreenSaver *kss_create( WId d )
+    KDE_EXPORT KScreenSaver *kss_create( WId d )
     {
         KGlobal::locale()->insertCatalogue("kpartsaver");
         return new KPartSaver( d );
     }
 
-    QDialog *kss_setup()
+    KDE_EXPORT QDialog *kss_setup()
     {
         kdDebug() << "kss_setup" << endl;
         KGlobal::locale()->insertCatalogue("kpartsaver");
@@ -295,8 +295,8 @@ SaverConfig::SaverConfig( QWidget* parent, const char* name )
     connect( m_up, SIGNAL(clicked()), SLOT(up()) );
     connect( m_down, SIGNAL(clicked()), SLOT(down()) );
 
-    m_up->setPixmap( SmallIcon("up") );
-    m_down->setPixmap( SmallIcon("down") );
+    m_up->setIconSet( SmallIconSet("up") );
+    m_down->setIconSet( SmallIconSet("down") );
 
     // load config
     KConfig *cfg = kapp->config();
