@@ -2,7 +2,7 @@
  *
  *            kStart OpenGL screensave for KDE
  *
- * $Id: space.cpp,v 1.5 2002/07/03 10:54:28 binner Exp $
+ * $Id$
  *
  *            Copyright (C) 1998 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  * Based on star.c:
  *
@@ -210,7 +210,7 @@ GLenum StarPoint(GLint n)
 	    y1 += windH / 2.0;
 
 	    glLineWidth(MAXPOS/100.0/stars[n].z[0]+1.0);
-	    glColor3f(1.0, (MAXWARP1-speed)/MAXWARP1, (MAXWARP1-speed)/MAXWARP1);
+	    glColor3f((MAXWARP1-speed)/MAXWARP1, (MAXWARP1-speed)/MAXWARP1, .9);
 	    if (fabs(x0-x1) < 1.0 && fabs(y0-y1) < 1.0) {
 		glBegin(GL_POINTS);
 		    glVertex2f(x0, y0);
@@ -577,13 +577,14 @@ void kSpaceSaver::slotTimeout()
 
 kSpaceSetup::kSpaceSetup( QWidget *parent, const char *name )
 	: KDialogBase( parent, name, true, i18n("Setup Space Screen Saver"),
-		       Ok|Cancel|User1, Ok, false, i18n("About") )
+		       Ok|Cancel|Help, Ok, true )
 {
+    setButtonText( Help, i18n( "A&bout" ) );
     readSettings();
 
     QWidget *page = new QWidget( this );
     setMainWidget( page );
-    QHBoxLayout *hb = new QHBoxLayout( page, spacingHint() );
+    QHBoxLayout *hb = new QHBoxLayout( page, 0, spacingHint() );
     QVBoxLayout *vb = new QVBoxLayout( hb, spacingHint() );
 
     QLabel *label;
@@ -599,19 +600,17 @@ kSpaceSetup::kSpaceSetup( QWidget *parent, const char *name )
     slider->setTickInterval(10);
     connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
 
-    vb->addSpacing( 10 );
     label = new QLabel( i18n("Warp interval:"), page );
     vb->addWidget( label );
 
-    slider = new QSlider(MINWARP, MAXWARP, 3, warpinterval,
-		    QSlider::Horizontal, page );
+    slider = new QSlider(MINWARP, MAXWARP, 3, warpinterval, Horizontal, page );
     vb->addWidget( slider );
     slider->setTickmarks(QSlider::Below);
     slider->setTickInterval(3);
     connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotWarp( int ) ) );
 
     vb->addStrut( 150 );
-    vb->addStretch( 1 );
+    vb->addStretch();
 
     preview = new QWidget( page );
     hb->addWidget( preview );
@@ -619,8 +618,6 @@ kSpaceSetup::kSpaceSetup( QWidget *parent, const char *name )
     preview->setBackgroundColor( black );
     preview->show();    // otherwise saver does not get correct size
     saver = new kSpaceSaver( preview->winId() );
-
-    connect( this, SIGNAL( user1Clicked() ), SLOT( slotAbout() ) );
 }
 
 void kSpaceSetup::readSettings()
@@ -673,7 +670,7 @@ void kSpaceSetup::slotOk()
 	accept();
 }
 
-void kSpaceSetup::slotAbout()
+void kSpaceSetup::slotHelp()
 {
 	KMessageBox::about(this,
 		i18n("KSpace\nCopyright (c) 1998\n"
