@@ -1,5 +1,5 @@
 /*
- *	$Id: cdeclient.cpp,v 1.21 2003/12/15 15:14:44 lunakl Exp $
+ *	$Id: cdeclient.cpp 409718 2005-05-05 12:52:18Z lunakl $
  *
  *	CDE KWin client - emulates the look and feel
  *	of dtwm, the CDE window manager.
@@ -9,8 +9,8 @@
  *		Lennart Kudling <kudling@kde.org>
  *      	Fredrik Hglund <fredrik@kde.org>
  *
- *	Copyright (c) 2003
- *		Luciano Montanaro <mikelima@virgilio.it>
+ *	Copyright (c) 2003,2004
+ *		Luciano Montanaro <mikelima@cirulla.net>
  *
  *	Originally based on the KStep client.
  *
@@ -30,7 +30,7 @@
 #include <klocale.h>
 #include <kconfig.h>
 
-extern "C" KDecorationFactory* create_factory()
+extern "C" KDE_EXPORT KDecorationFactory* create_factory()
 {
     return new CDE::CdeClientFactory();
 }
@@ -231,6 +231,23 @@ bool CdeClientFactory::reset(unsigned long /*changed*/)
     return true;
 }
 
+bool CdeClientFactory::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonMenu:
+        case AbilityButtonOnAllDesktops:
+        case AbilityButtonHelp:
+        case AbilityButtonMinimize:
+        case AbilityButtonMaximize:
+        case AbilityButtonClose:
+            return true;
+        default:
+            return false;
+    };
+}
+
 QValueList< CdeClientFactory::BorderSize >
 CdeClientFactory::borderSizes() const
 {
@@ -417,19 +434,10 @@ void CdeClient::resize(const QSize& s)
 void CdeClient::maximizeButtonClicked()
 {
     if (button[BtnMax]) {
-        switch (button[BtnMax]->lastButton()) {
-        case MidButton:
-	    maximize(maximizeMode() ^ MaximizeVertical);
-            break;
-        case RightButton:
-	    maximize(maximizeMode() ^ MaximizeHorizontal);
-            break;
-        default:
-	    maximize(maximizeMode() == MaximizeFull ? MaximizeRestore : MaximizeFull);
-            break;
-        }
+	maximize(button[BtnMax]->lastButton());
     }
 }
+
 void CdeClient::menuButtonPressed()
 {
     static QTime* t = NULL;
@@ -441,10 +449,12 @@ void CdeClient::menuButtonPressed()
     t->start();
     if( !dbl )
     {
-        QPoint pos = button[BtnMenu]->mapToGlobal(
-		button[BtnMenu]->rect().bottomLeft());
+	QRect menuRect = button[BtnMenu]->rect();
+        QPoint menuTop = button[BtnMenu]->mapToGlobal(menuRect.topLeft());
+        QPoint menuBottom = 
+	    button[BtnMenu]->mapToGlobal(menuRect.bottomRight());
         KDecorationFactory* f = factory();
-	showWindowMenu(pos);
+        showWindowMenu(QRect(menuTop, menuBottom));
         if( !f->exists( this )) // 'this' was deleted
             return;
 	button[BtnMenu]->setDown(false);
@@ -702,7 +712,7 @@ KDecoration::Position CdeClient::mousePosition( const QPoint& p ) const
 
 void CdeClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-    if ( titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
 	titlebarDblClickOperation();
 }
 
