@@ -116,7 +116,7 @@ QString GlowButton::getPixmapName() const
 	return m_pixmapName;
 }
 
-int GlowButton::lastButton() const
+Qt::ButtonState GlowButton::lastButton() const
 {
 	return _last_button;
 }
