@@ -26,7 +26,7 @@
 #include <klocale.h>
 #include <kpixmapeffect.h>
 #include <kpixmap.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <qlabel.h>
 #include "resources.h"
 #include "glowclient.h"
@@ -167,7 +167,7 @@ void GlowClientGlobals::readTheme()
 	QString theme_config_file = KGlobal::dirs()->findResource ("data",
 			QString("kwin/glow-themes/") + config()->themeName + "/" +
 			config()->themeName + ".theme");
-	if (theme_config_file == QString::null)
+	if (theme_config_file.isNull())
 	{
 		config()->themeName = "default";
 		return;
@@ -232,6 +232,23 @@ bool GlowClientGlobals::reset( unsigned long changed )
 	return true; // FRAME
 }
 
+bool GlowClientGlobals::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonOnAllDesktops:
+        case AbilityButtonSpacer:
+        case AbilityButtonHelp:
+        case AbilityButtonMinimize:
+        case AbilityButtonMaximize:
+        case AbilityButtonClose:
+            return true;
+        default:
+            return false;
+    };
+}
+
 bool GlowClientGlobals::createPixmaps()
 {
 	for( int type=0; type<=Close; type++ ) {
@@ -497,7 +514,7 @@ void GlowClient::showEvent( QShowEvent * )
 
 void GlowClient::mouseDoubleClickEvent( QMouseEvent *e )
 {
-	if(_title_spacer->geometry().contains(e->pos()))
+	if(e->button() == LeftButton && _title_spacer->geometry().contains(e->pos()))
 		titlebarDblClickOperation();
 }
 
@@ -548,12 +565,12 @@ void GlowClient::desktopChange()
 		m_stickyButton->setPixmapName(
 			GlowClientGlobals::instance()->getPixmapName(
 				GlowClientGlobals::StickyOn, isActive()));
-		m_stickyButton->setTipText(i18n("Not On All Desktops"));
+		m_stickyButton->setTipText(i18n("Not on all desktops"));
 	} else {
 		m_stickyButton->setPixmapName(
 			GlowClientGlobals::instance()->getPixmapName(
 				GlowClientGlobals::StickyOff, isActive()));
-		m_stickyButton->setTipText(i18n("On All Desktops"));
+		m_stickyButton->setTipText(i18n("On all desktops"));
 	}
 }
 
@@ -614,7 +631,7 @@ void GlowClient::createButtons()
 	QSize size = globals->theme()->buttonSize;
 
 	m_stickyButton = factory->createGlowButton(widget(),
-					"StickyButton", isOnAllDesktops()?i18n("Not On All Desktops"):i18n("On All Desktops"), LeftButton|RightButton);
+					"StickyButton", isOnAllDesktops()?i18n("Not on all desktops"):i18n("On all desktops"), LeftButton|RightButton);
 	m_stickyButton->setFixedSize(size);
 	connect(m_stickyButton, SIGNAL(clicked()), this, SLOT(toggleOnAllDesktops()));
 	m_buttonList.insert(m_buttonList.end(), m_stickyButton);
@@ -680,7 +697,7 @@ void GlowClient::resetLayout()
 	midLayout->addSpacing(SIDE_MARGIN);
 	if(isPreview())
 		midLayout->addWidget(
-				new QLabel( i18n( "<b><center>Glow</center></b>" ), widget()));
+				new QLabel( i18n( "<b><center>Glow preview</center></b>" ), widget()));
 	else
 		midLayout->addItem( new QSpacerItem( 0, 0 ));
 	midLayout->addSpacing(SIDE_MARGIN);
@@ -817,12 +834,7 @@ bool GlowClient::isRight(GlowButton *button)
 
 void GlowClient::slotMaximize()
 {
-	if(m_maximizeButton->lastButton() == QMouseEvent::RightButton)
-		maximize( maximizeMode() ^ MaximizeHorizontal);
-	else if(m_maximizeButton->lastButton() == QMouseEvent::MidButton)
-		maximize( maximizeMode() ^ MaximizeVertical);
-	else  // left button
-		maximize( maximizeMode() == MaximizeFull ? MaximizeRestore : MaximizeFull );
+	maximize(m_maximizeButton->lastButton());
 }
 
 bool GlowClient::eventFilter( QObject* o, QEvent* e )
@@ -860,7 +872,7 @@ KDecoration* GlowClientGlobals::createDecoration( KDecorationBridge* bridge )
 } // end of namespace
 
 extern "C"
-KDecorationFactory* create_factory()
+KDE_EXPORT KDecorationFactory* create_factory()
 {
 	return Glow::GlowClientGlobals::instance();
 }
