@@ -19,6 +19,10 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 
 #include "kde1client_bitmaps.h"
 
+// Default button layout
+const char default_left[]  = "MS";
+const char default_right[] = "H_IAX";
+
 namespace KDE1
 {
 
@@ -217,15 +221,19 @@ void drawGradient
 
 void StdClient::reset( unsigned long )
 {
-    if(icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull())
-        button[0]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
-    button[1]->setIconSet(isOnAllDesktops() ? isActive() ? *pindown_pix : *dis_pindown_pix :
-                          isActive() ? *pinup_pix : *dis_pinup_pix );
-    button[3]->setIconSet(isActive() ? *minimize_pix : *dis_minimize_pix);
-    button[4]->setIconSet(isActive() ? *maximize_pix : *dis_maximize_pix);
-    button[5]->setIconSet(isActive() ? *close_pix : *dis_close_pix);
-    if (button[6])
-        button[6]->setIconSet(isActive() ? *question_mark_pix : *dis_question_mark_pix);
+    if (button[ButtonMenu] && (icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull()))
+        button[ButtonMenu]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
+    if (button[ButtonSticky])
+        button[ButtonSticky]->setIconSet(isOnAllDesktops() ? isActive() ? *pindown_pix : *dis_pindown_pix :
+                                         isActive() ? *pinup_pix : *dis_pinup_pix );
+    if (button[ButtonMinimize])
+        button[ButtonMinimize]->setIconSet(isActive() ? *minimize_pix : *dis_minimize_pix);
+    if (button[ButtonMaximize])
+        button[ButtonMaximize]->setIconSet(isActive() ? *maximize_pix : *dis_maximize_pix);
+    if (button[ButtonClose])
+        button[ButtonClose]->setIconSet(isActive() ? *close_pix : *dis_close_pix);
+    if (button[ButtonHelp])
+        button[ButtonHelp]->setIconSet(isActive() ? *question_mark_pix : *dis_question_mark_pix);
 
     widget()->setFont(options()->font(true));
 }
@@ -246,7 +254,7 @@ void StdClient::init()
     QGridLayout* g = new QGridLayout( widget(), 0, 0, 3, 2 );
     g->setRowStretch( 1, 10 );
     if( isPreview())
-        g->addWidget( new QLabel( i18n( "<center><b>KDE 1 decoration</b></center>" ), widget()), 1, 1 );
+        g->addWidget( new QLabel( i18n( "<center><b>KDE 1 preview</b></center>" ), widget()), 1, 1 );
     else
         g->addItem( new QSpacerItem( 0, 0 ), 1, 1 ); //no widget in the middle
     g->addItem( new QSpacerItem( 0, 0, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
@@ -255,85 +263,28 @@ void StdClient::init()
     g->addColSpacing(2, 1);
     g->addRowSpacing(2, 1);
 
-
-    button[0] = new QToolButton( widget(), 0 );
-    QToolTip::add( button[ 0 ], i18n("Menu") );
-    button[1] = new QToolButton( widget(), 0 );
-    button[1]->setIconSet( isOnAllDesktops()?*pindown_pix:*pinup_pix );
-    QToolTip::add( button[ 1 ], isOnAllDesktops()?i18n("Unsticky"):i18n("Sticky")  );
-//    button[2] = new KWinToolButton( this, 0, i18n("?") );
-    button[2] = NULL;
-    button[3] = new QToolButton( widget(), 0 );
-    QToolTip::add( button[ 3 ], i18n("Minimize") );
-    button[4] = new ThreeButtonButton( widget(), 0 );
-    QToolTip::add( button[ 4 ], i18n("Maximize") );
-    button[5] = new QToolButton( widget(), 0 );
-    QToolTip::add( button[ 5 ], i18n("Close") );
-
-    // explicitly set ArrowCursor.
-    button[0]->setCursor(ArrowCursor);
-    button[1]->setCursor(ArrowCursor);
-    button[3]->setCursor(ArrowCursor);
-    button[4]->setCursor(ArrowCursor);
-    button[5]->setCursor(ArrowCursor);
+    int fh = widget()->fontMetrics().lineSpacing();
+    titlebar = new QSpacerItem(10, fh, QSizePolicy::Expanding,
+			       QSizePolicy::Minimum );
 
     QBoxLayout* hb = new QBoxLayout(0, QBoxLayout::LeftToRight, 0, 0, 0);
     g->addLayout( hb, 0, 1 );
-    hb->addWidget( button[0] );
-    hb->addWidget( button[1] );
-//    hb->addWidget( button[2] );
 
-    int fh = widget()->fontMetrics().lineSpacing();
+    // setup titlebar buttons
+    for (int n=0; n<ButtonTypeCount; n++) button[n] = 0;
+    addButtons(hb, options()->customButtonPositions() ? options()->titleButtonsLeft() : QString(default_left));
+    hb->addItem(titlebar);
+    addButtons(hb, options()->customButtonPositions() ? options()->titleButtonsRight() : QString(default_right));
 
-    titlebar = new QSpacerItem(10, fh, QSizePolicy::Expanding,
-			       QSizePolicy::Minimum );
-    hb->addItem( titlebar );
-
-    button[6] = 0;
-    if ( providesContextHelp() ) {
-	button[6] = new QToolButton( widget(), 0 );
-        QToolTip::add( button[ 6 ], i18n("Help") );
-	hb->addWidget( button[6] ); // help  button
-	hb->addItem( new QSpacerItem( 5, 0, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
-	button[6]->setIconSet( isActive() ? *question_mark_pix : *dis_question_mark_pix);
-	connect( button[6], SIGNAL( clicked() ), this, ( SLOT( showContextHelp() ) ) );
-	button[6]->setCursor(ArrowCursor);
-    }
-
-    hb->addWidget( button[3] );
-    hb->addWidget( button[4] );
-    hb->addWidget( button[5] );
-
-    for ( int i = 0; i < 7; i++) {
-	if ( !button[i] )
+    for (int n=0; n<ButtonTypeCount; n++) {
+	if ( !button[n] )
 	    continue;
-	button[i]->setBackgroundMode( PaletteBackground );
-	button[i]->setMouseTracking( FALSE );
-	button[i]->setAutoRaise( TRUE );
-	button[i]->setFocusPolicy( QWidget::NoFocus );
-	button[i]->setFixedSize( 20, 20 );
+	button[n]->setBackgroundMode( PaletteBackground );
+	button[n]->setMouseTracking( FALSE );
+	button[n]->setAutoRaise( TRUE );
+	button[n]->setFocusPolicy( QWidget::NoFocus );
+	button[n]->setFixedSize( 20, 20 );
     }
-    if( icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull())
-        button[0]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
-    else
-        button[0]->setIconSet( icon().pixmap( QIconSet::Small, QIconSet::Normal ));
-
-    connect( button[0], SIGNAL( pressed() ), this, SLOT( menuButtonPressed() ) );
-    button[1]->setIconSet(isOnAllDesktops() ? isActive() ? *pindown_pix : *dis_pindown_pix :
-                          isActive() ? *pinup_pix : *dis_pinup_pix );
-    connect( button[1], SIGNAL( clicked() ), this, ( SLOT( toggleOnAllDesktops() ) ) );
-//    button[2]->hide();
-
-    button[3]->setIconSet(isActive() ? *minimize_pix : *dis_minimize_pix);
-    connect( button[3], SIGNAL( clicked() ), this, ( SLOT( minimize() ) ) );
-    button[4]->setIconSet(isActive() ? *maximize_pix : *dis_maximize_pix);
-    connect( button[4], SIGNAL( clicked(ButtonState) ), this, ( SLOT( maxButtonClicked(ButtonState) ) ) );
-    button[5]->setIconSet(isActive() ? *close_pix : *dis_close_pix);
-    connect( button[5], SIGNAL( clicked() ), this, ( SLOT( closeWindow() ) ) );
-
-    if ( button[6] ) {
-    }
-
 
 #if 0 // not sure what this is supposed to mean (and why)
     if ( isTransient() ) {
@@ -346,24 +297,116 @@ void StdClient::init()
 #endif
 }
 
+void StdClient::addButtons(QBoxLayout *hb, const QString& s)
+{
+    if (s.length() > 0) {
+        for (unsigned n=0; n < s.length(); n++) {
+            switch (s[n]) {
+              case 'M': // Menu button
+                  if (!button[ButtonMenu]) {
+                      button[ButtonMenu] = new QToolButton( widget(), 0 );
+                      QToolTip::add( button[ButtonMenu], i18n("Menu") );
+                      button[ButtonMenu]->setCursor(ArrowCursor);
+                      if( icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull())
+                          button[ButtonMenu]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
+                      else
+                          button[ButtonMenu]->setIconSet( icon().pixmap( QIconSet::Small, QIconSet::Normal ));
+                      connect( button[0], SIGNAL( pressed() ), this, SLOT( menuButtonPressed() ) );
+                      hb->addWidget(button[ButtonMenu]);
+                  }
+                  break;
+
+              case 'S': // Sticky button
+                  if (!button[ButtonSticky]) {
+                     button[ButtonSticky] = new QToolButton( widget(), 0 );
+                     button[ButtonSticky]->setIconSet( isOnAllDesktops()?*pindown_pix:*pinup_pix );
+                     QToolTip::add( button[ButtonSticky], isOnAllDesktops()?i18n("Not On All Desktops"):i18n("On All Desktops")  );
+                     button[ButtonSticky]->setCursor(ArrowCursor);
+                     button[ButtonSticky]->setIconSet(isOnAllDesktops() ? isActive() ? *pindown_pix : *dis_pindown_pix :
+                                                      isActive() ? *pinup_pix : *dis_pinup_pix );
+                     connect( button[ButtonSticky], SIGNAL( clicked() ), this, ( SLOT( toggleOnAllDesktops() ) ) );
+                     hb->addWidget(button[ButtonSticky]);
+                  }
+                  break;
+
+              case 'H': // Help button
+                  if ((!button[ButtonHelp]) && providesContextHelp()) {
+                      button[ButtonHelp] = new QToolButton( widget(), 0 );
+                      QToolTip::add( button[ButtonHelp], i18n("Help") );
+                      button[ButtonHelp]->setIconSet( isActive() ? *question_mark_pix : *dis_question_mark_pix);
+                      connect( button[ButtonHelp], SIGNAL( clicked() ), this, ( SLOT( showContextHelp() ) ) );
+                      button[ButtonHelp]->setCursor(ArrowCursor);
+                      hb->addWidget(button[ButtonHelp]);
+                  }
+                  break;
+
+              case 'I': // Minimize button
+                  if ((!button[ButtonMinimize]) && isMinimizable())  {
+                      button[ButtonMinimize] = new QToolButton( widget(), 0 );
+                      QToolTip::add( button[ButtonMinimize], i18n("Minimize") );
+                      button[ButtonMinimize]->setCursor(ArrowCursor);
+                      button[ButtonMinimize]->setIconSet(isActive() ? *minimize_pix : *dis_minimize_pix);
+                      connect( button[ButtonMinimize], SIGNAL( clicked() ), this, ( SLOT( minimize() ) ) );
+                      hb->addWidget(button[ButtonMinimize]);
+                  }
+                  break;
+
+              case 'A': // Maximize button
+                  if ((!button[ButtonMaximize]) && isMaximizable()) {
+                      const bool max = maximizeMode()!=MaximizeRestore;
+                      button[ButtonMaximize] = new ThreeButtonButton( widget(), 0 );
+                      QToolTip::add( button[ButtonMaximize], max?i18n("Restore"):i18n("Maximize") );
+                      button[ButtonMaximize]->setCursor(ArrowCursor);
+                      button[ButtonMaximize]->setIconSet( max?(isActive() ? *normalize_pix : *dis_normalize_pix):(isActive() ? *maximize_pix : *dis_maximize_pix) );
+                      connect( button[ButtonMaximize], SIGNAL( clicked(ButtonState) ),
+                               this, ( SLOT( maxButtonClicked(ButtonState) ) ) );
+                      hb->addWidget(button[ButtonMaximize]);
+                  }
+                  break;
+
+              case 'X': // Close button
+                  if ((!button[ButtonClose]) && isCloseable()) {
+                      button[ButtonClose] = new QToolButton( widget(), 0 );
+                      QToolTip::add( button[ButtonClose], i18n("Close") );
+                      button[ButtonClose]->setCursor(ArrowCursor);
+                      button[ButtonClose]->setIconSet(isActive() ? *close_pix : *dis_close_pix);
+                      connect( button[ButtonClose], SIGNAL( clicked() ), this, ( SLOT( closeWindow() ) ) );
+                      hb->addWidget(button[ButtonClose]);
+                  }
+                  break;
+
+              case '_': // Spacer item
+	          hb->addItem( new QSpacerItem( 5, 0, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
+            }
+        }
+    }
+}
+
 void StdClient::activeChange()
 {
     bool on = isActive();
-    if( icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull())
-        button[0]->setIconSet(on ? *menu_pix : *dis_menu_pix);
-    button[1]->setIconSet(isOnAllDesktops() ? on ? *pindown_pix : *dis_pindown_pix :
+    if (button[ButtonMenu] && (icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull()))
+        button[ButtonMenu]->setIconSet(on ? *menu_pix : *dis_menu_pix);
+    if (button[ButtonSticky])
+        button[ButtonSticky]->setIconSet(isOnAllDesktops() ? on ? *pindown_pix : *dis_pindown_pix :
                           on ? *pinup_pix : *dis_pinup_pix );
-    button[3]->setIconSet(on ? *minimize_pix : *dis_minimize_pix);
-    button[4]->setIconSet(on ? *maximize_pix : *dis_maximize_pix);
-    button[5]->setIconSet(on ? *close_pix : *dis_close_pix);
-    if (button[6])
-	button[6]->setIconSet(on ? *question_mark_pix : *dis_question_mark_pix);
+    if (button[ButtonMinimize])
+        button[ButtonMinimize]->setIconSet(on ? *minimize_pix : *dis_minimize_pix);
+    if (button[ButtonMaximize])
+        button[ButtonMaximize]->setIconSet(on ? *maximize_pix : *dis_maximize_pix);
+    if (button[ButtonClose])
+        button[ButtonClose]->setIconSet(on ? *close_pix : *dis_close_pix);
+    if (button[ButtonHelp])
+        button[ButtonHelp]->setIconSet(on ? *question_mark_pix : *dis_question_mark_pix);
     widget()->repaint( titlebar->geometry(), false );
 }
 
 
 StdClient::~StdClient()
 {
+    for (int n=0; n<ButtonTypeCount; n++) {
+        if (button[n]) delete button[n];
+    }
 }
 
 
@@ -395,9 +438,11 @@ void StdClient::captionChange()
 void StdClient::maximizeChange()
 {
     bool m = maximizeMode() == MaximizeFull;
-    button[4]->setIconSet( m?*normalize_pix:*maximize_pix  );
-    QToolTip::remove( button[ 4 ] );
-    QToolTip::add( button[4], m ? i18n("Restore") : i18n("Maximize") );
+    if (button[ButtonMaximize]) {
+        button[ButtonMaximize]->setIconSet( m?*normalize_pix:*maximize_pix  );
+        QToolTip::remove( button[ButtonMaximize] );
+        QToolTip::add( button[ButtonMaximize], m ? i18n("Restore") : i18n("Maximize") );
+    }
 }
 
 
@@ -406,9 +451,11 @@ void StdClient::maximizeChange()
 void StdClient::desktopChange()
 {
     bool s = isOnAllDesktops();
-    button[1]->setIconSet( s?*pindown_pix:*pinup_pix );
-    QToolTip::remove( button[ 1 ] );
-    QToolTip::add( button[1], s ? i18n("Unsticky") : i18n("Sticky") );
+    if (button[ButtonSticky]) {
+        button[ButtonSticky]->setIconSet( s?*pindown_pix:*pinup_pix );
+        QToolTip::remove( button[ButtonSticky] );
+        QToolTip::add( button[ButtonSticky], s ? i18n("Not On All Desktops") : i18n("On All Desktops") );
+    }
 }
 
 void StdClient::paintEvent( QPaintEvent* )
@@ -426,7 +473,7 @@ void StdClient::paintEvent( QPaintEvent* )
     QRect titleRect( 0, 0, t.width(), t.height() );
     titleBuffer->resize( titleRect.width(), titleRect.height() );
     QPainter p2( titleBuffer );
-    
+
     drawGradient(p2, titleRect, options()->color(KDecorationOptions::ColorTitleBar, isActive()),
         options()->color(KDecorationOptions::ColorTitleBlend, isActive()));
 //     p.setPen( options()->color(KDecorationOptions::ColorTitleBar, isActive()).light() );
@@ -447,18 +494,20 @@ void StdClient::paintEvent( QPaintEvent* )
 
 void StdClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-    if ( titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
 	titlebarDblClickOperation();
 }
 
 
 void StdClient::iconChange()
 {
-    if( icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull())
-        button[0]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
-    else
-        button[0]->setIconSet( icon().pixmap( QIconSet::Small, QIconSet::Normal ) );
-    button[0]->repaint( FALSE );
+    if (button[ButtonMenu]) {
+        if ( icon().pixmap( QIconSet::Small, QIconSet::Normal ).isNull())
+            button[ButtonMenu]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
+        else
+            button[ButtonMenu]->setIconSet( icon().pixmap( QIconSet::Small, QIconSet::Normal ) );
+        button[ButtonMenu]->repaint( FALSE );
+    }
 }
 
 
@@ -468,15 +517,15 @@ void StdClient::iconChange()
  */
 void StdClient::menuButtonPressed()
 {
-    QRect menuRect = button[0]->rect();
+    QRect menuRect = button[ButtonMenu]->rect();
     menuRect.addCoords(-1, 0, +1, +2);
-    QPoint menuTop = button[0]->mapToGlobal(menuRect.topLeft());
-    QPoint menuBottom = button[0]->mapToGlobal(menuRect.bottomRight());
+    QPoint menuTop = button[ButtonMenu]->mapToGlobal(menuRect.topLeft());
+    QPoint menuBottom = button[ButtonMenu]->mapToGlobal(menuRect.bottomRight());
     KDecorationFactory* f = factory(); // needs to be saved before
     showWindowMenu( QRect(menuTop, menuBottom) );
     if( !f->exists( this )) // destroyed, return immediately
         return;
-    button[0]->setDown(false);
+    button[ButtonMenu]->setDown(false);
 }
 
 
@@ -605,7 +654,7 @@ void StdToolClient::paintEvent( QPaintEvent* )
 
 void StdToolClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-    if ( titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
         titlebarDblClickOperation();
 }
 
@@ -701,18 +750,36 @@ bool StdFactory::reset( unsigned long mask )
         KDE1::delete_pixmaps();
         KDE1::create_pixmaps();
     }
-    
+
     if( !needHardReset )
         resetDecorations( mask );
     return needHardReset;
 }
 
+bool StdFactory::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonMenu:
+        case AbilityButtonOnAllDesktops:
+        case AbilityButtonHelp:
+        case AbilityButtonMinimize:
+        case AbilityButtonMaximize:
+        case AbilityButtonClose:
+        case AbilityButtonSpacer:
+            return true;
+        default:
+            return false;
+    };
+}
+
 
 }
 
 extern "C"
 {
-	KDecorationFactory *create_factory()
+	KDE_EXPORT KDecorationFactory *create_factory()
 	{
                 return new KDE1::StdFactory();
 	}
