@@ -39,7 +39,7 @@
 
 #include "OpenLook.h"
 
-extern "C" KDecorationFactory* create_factory()
+extern "C" KDE_EXPORT KDecorationFactory* create_factory()
 {
     return new OpenLook::DecorationFactory();
 }
@@ -74,6 +74,18 @@ bool DecorationFactory::reset(unsigned long /*changed*/)
     return true;
 }
 
+bool DecorationFactory::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonMinimize:
+            return true;
+        default:
+            return false;
+    };
+}
+
 QValueList< DecorationFactory::BorderSize > 
 DecorationFactory::borderSizes() const
 { 
@@ -263,7 +275,7 @@ OpenLook::showEvent(QShowEvent *)
   void
 OpenLook::mouseDoubleClickEvent(QMouseEvent * e)
 {
-  if (titleRect().contains(e->pos()))
+  if (e->button() == LeftButton && titleRect().contains(e->pos()))
   {
 	  titlebarDblClickOperation();
   }
@@ -335,7 +347,7 @@ OpenLook::doLayout()
  
   if (isPreview()) {
     midLayout->addWidget(new QLabel(
-          i18n("<center><b></b>OpenLook preview</center>"), 
+          i18n("<center><b>OpenLook preview</b></center>"), 
           widget()), 
         1);
   } else {
