@@ -349,7 +349,7 @@ KDecoration::Position Manager::mousePosition(const QPoint& p) const
 
 void Manager::mouseDoubleClickEvent(QMouseEvent *e)
 {
-   if (titleSpacer_->geometry().contains(e->pos()))
+   if (e->button() == LeftButton && titleSpacer_->geometry().contains(e->pos()))
       titlebarDblClickOperation();
 }
 
