@@ -71,6 +71,7 @@ class Manager : public KDecoration
 
    public slots:
 
+      void slotAbove();
       void slotLower();
       void slotMaximizeClicked(ButtonState);
       void slotToggleSticky();
@@ -111,6 +112,7 @@ class Factory : public QObject, public KDecorationFactory
       ~Factory();
       virtual bool reset(unsigned long changed);
       virtual KDecoration* createDecoration(KDecorationBridge*);
+      virtual bool supports( Ability ability );
 };
 
 } // End namespace
