@@ -604,7 +604,7 @@ void SystemClient::showEvent(QShowEvent *)
 
 void SystemClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-   if (titlebar->geometry().contains( e->pos() ) )
+   if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
       titlebarDblClickOperation();
 }
 
