@@ -29,6 +29,7 @@
 #include <qpointarray.h>
 #include <qpainter.h>
 #include <qtabbar.h>
+#include <qtabwidget.h>
 #include <qprogressbar.h>
 #include <qcombobox.h>
 #include <qlistbox.h>
@@ -69,7 +70,7 @@ class dotNETstylePlugin : public QStylePlugin
 		}
 };
 
-Q_EXPORT_PLUGIN( dotNETstylePlugin )
+KDE_Q_EXPORT_PLUGIN( dotNETstylePlugin )
 
 // ---------------------------------------------------
 
@@ -204,12 +205,13 @@ void dotNETstyle::renderButton(QPainter *p,
 				p->drawRect(r);
 			}
 
-			p->setPen(g.button().light());
-			p->drawLine(x + 1, y + 1, x + 1, y + h - 2);
-			p->drawLine(x + 1, y + 1, x + w - 2, y + 1);
+			const QCOORD oCorners[] = { x + 1, y + h - 2, x + 1, y + 1, x + w - 2, y + 1, x + w - 2, y + h - 2 };
+			const QPointArray outline(4, oCorners);
 			p->setPen(g.button().dark(115));
-			p->drawLine(x + 2, y + h - 2, x + w - 2, y + h - 2);
-			p->drawLine(x + w - 2, y + 2, x + w - 2, y + h - 2);
+			p->setBrush(QBrush::NoBrush);
+			p->drawConvexPolygon(outline);
+			p->setPen(g.button().light());
+			p->drawPolyline(outline, 0, 3);
 		} else {
 			p->setPen(g.button().dark());
 			p->setBrush(g.button());
@@ -749,7 +751,7 @@ void dotNETstyle::drawPrimitive(PrimitiveElement pe,
 		}
 
 		default: {
-			return winstyle->drawPrimitive(pe, p, r, cg, flags, opt);
+			return KStyle::drawPrimitive(pe, p, r, cg, flags, opt);
 		}
 	}
 }
@@ -816,7 +818,7 @@ void dotNETstyle::drawControl(ControlElement element,
 				if (pseudo3D) {
 					QPointArray corners;
 					if (reverseLayout) {
-						const QCOORD c[] = { x, y, w + x, y, w + x, h, x, h };
+						const QCOORD c[] = { x, h, x, y, x + w, y, x + w, h };
 						corners = QPointArray(4, c);
 					} else {
 						const QCOORD c[] = { x, h, x, y, w, y, w, h };
@@ -853,13 +855,22 @@ void dotNETstyle::drawControl(ControlElement element,
 	//	TABS
 	//	----
 		case CE_TabBarTab: {
-			const QTabBar * tb = (const QTabBar *) widget;
+			const QTabBar *tb = (const QTabBar *) widget;
+			bool cornerWidget = false;
 			QTabBar::Shape tbs = tb->shape();
 			bool selected = flags & Style_Selected;
 			int x, x2, y, y2, w, h;
 			r.rect(&x, &y, &w, &h);
 			r.coords(&x, &y, &x2, &y2);
 
+			if (tb->parent()->inherits("QTabWidget")) {
+				const QTabWidget *tw = (const QTabWidget *)tb->parent();
+				QWidget *cw = tw->cornerWidget(Qt::TopLeft);
+				if (cw) {
+					cornerWidget = true;
+				}
+			}
+
 			switch (tbs) {
 				case QTabBar::RoundedAbove: {
 					y2 -= 1;
@@ -906,7 +917,7 @@ void dotNETstyle::drawControl(ControlElement element,
 							p->drawLine(x + w - 1, y + 3, x + w - 1, y + h - 2);
     					}
 
-						if (opt.tab()->identifier() == 0) {
+						if (opt.tab()->identifier() == 0 && !cornerWidget) {
 							p->setPen(cg.background().dark());
 							p->drawPoint(x, y + h - 1);
 						}
@@ -980,7 +991,7 @@ void dotNETstyle::drawControl(ControlElement element,
 							}
     					}
 
-						if (opt.tab()->identifier() == 0) {
+						if (opt.tab()->identifier() == 0 && !cornerWidget) {
 							p->setPen(cg.background().dark());
 							p->drawPoint(x, y);
 						}
@@ -1962,13 +1973,12 @@ QSize dotNETstyle::sizeFromContents(ContentsType t,
 
 			if ( h < 22 )
 				h = 22;
-
 			return QSize( w, h );
 		}
 
 		case CT_ComboBox: {
 			int arrow = 21;
-			return QSize( s.width() + arrow, QMAX(s.height() + 4, 16));
+			return QSize(s.width() + arrow, QMAX(s.height() + 4, 16));
 		}
 
 		default:
